@@ -10,7 +10,7 @@
  import os
  import re
  import shutil
-@@ -45,7 +48,7 @@ WEBP_ROOT = None
+@@ -46,7 +49,7 @@ WEBP_ROOT = None
  ZLIB_ROOT = None
  FUZZING_BUILD = "LIB_FUZZING_ENGINE" in os.environ
  
@@ -19,7 +19,7 @@
      import atexit
  
      atexit.register(
-@@ -160,7 +163,7 @@ def _find_library_dirs_ldconfig() -> lis
+@@ -163,7 +166,7 @@ def _find_library_dirs_ldconfig() -> lis
      args: list[str]
      env: dict[str, str]
      expr: str
@@ -28,7 +28,7 @@
          if struct.calcsize("l") == 4:
              machine = os.uname()[4] + "-32"
          else:
-@@ -182,7 +185,7 @@ def _find_library_dirs_ldconfig() -> lis
+@@ -185,7 +188,7 @@ def _find_library_dirs_ldconfig() -> lis
          env["LC_ALL"] = "C"
          env["LANG"] = "C"
  
@@ -37,7 +37,7 @@
          args = [ldconfig, "-r"]
          expr = r".* => (.*)"
          env = {}
-@@ -556,7 +559,7 @@ class pil_build_ext(build_ext):
+@@ -561,7 +564,7 @@ class pil_build_ext(build_ext):
          if self.disable_platform_guessing:
              pass
  
@@ -46,7 +46,7 @@
              # pythonX.Y.dll.a is in the /usr/lib/pythonX.Y/config directory
              self.compiler.shared_lib_extension = ".dll.a"
              _add_directory(
-@@ -566,7 +569,7 @@ class pil_build_ext(build_ext):
+@@ -571,7 +574,7 @@ class pil_build_ext(build_ext):
                  ),
              )
  
@@ -55,7 +55,7 @@
              # attempt to make sure we pick freetype2 over other versions
              _add_directory(include_dirs, "/sw/include/freetype2")
              _add_directory(include_dirs, "/sw/lib/freetype2/include")
-@@ -618,13 +621,13 @@ class pil_build_ext(build_ext):
+@@ -623,13 +626,13 @@ class pil_build_ext(build_ext):
                  for extension in self.extensions:
                      extension.extra_compile_args = ["-Wno-nullability-completeness"]
          elif (
@@ -73,7 +73,7 @@
                  # termux support for android.
                  # system libraries (zlib) are installed in /system/lib
                  # headers are at $PREFIX/include
-@@ -637,11 +640,11 @@ class pil_build_ext(build_ext):
+@@ -642,11 +645,11 @@ class pil_build_ext(build_ext):
                      ),
                  )
  
@@ -87,7 +87,7 @@
              _add_directory(library_dirs, "/opt/local/lib")
              _add_directory(include_dirs, "/opt/local/include")
  
-@@ -657,7 +660,7 @@ class pil_build_ext(build_ext):
+@@ -662,7 +665,7 @@ class pil_build_ext(build_ext):
              # alpine, at least
              _add_directory(library_dirs, "/lib")
  
@@ -96,7 +96,7 @@
              # on Windows, look for the OpenJPEG libraries in the location that
              # the official installer puts them
              program_files = os.environ.get("ProgramFiles", "")
-@@ -692,7 +695,7 @@ class pil_build_ext(build_ext):
+@@ -697,7 +700,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "zlib.h"):
                  if _find_library_file(self, "z"):
                      feature.set("zlib", "z")
@@ -105,7 +105,7 @@
                      feature.set("zlib", "zlib")  # alternative name
                  elif sys.platform == "win32" and _find_library_file(self, "zdll"):
                      feature.set("zlib", "zdll")  # dll import library
-@@ -702,7 +705,7 @@ class pil_build_ext(build_ext):
+@@ -707,7 +710,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "jpeglib.h"):
                  if _find_library_file(self, "jpeg"):
                      feature.set("jpeg", "jpeg")
@@ -114,7 +114,7 @@
                      feature.set("jpeg", "libjpeg")  # alternative name
  
          feature.set("openjpeg_version", None)
-@@ -754,7 +757,7 @@ class pil_build_ext(build_ext):
+@@ -759,7 +762,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "tiff.h"):
                  if _find_library_file(self, "tiff"):
                      feature.set("tiff", "tiff")
@@ -123,7 +123,7 @@
                      self, "libtiff"
                  ):
                      feature.set("tiff", "libtiff")
-@@ -860,7 +863,7 @@ class pil_build_ext(build_ext):
+@@ -871,7 +874,7 @@ class pil_build_ext(build_ext):
          if feature.get("tiff"):
              libs.append(feature.get("tiff"))
              defs.append(("HAVE_LIBTIFF", None))
@@ -132,7 +132,7 @@
                  # This define needs to be defined if-and-only-if it was defined
                  # when compiling LibTIFF. LibTIFF doesn't expose it in `tiffconf.h`,
                  # so we have to guess; by default it is defined in all Windows builds.
-@@ -872,7 +875,7 @@ class pil_build_ext(build_ext):
+@@ -883,7 +886,7 @@ class pil_build_ext(build_ext):
          if feature.get("jpeg2000"):
              libs.append(feature.get("jpeg2000"))
              defs.append(("HAVE_OPENJPEG", None))
@@ -141,7 +141,7 @@
                  defs.append(("OPJ_STATIC", None))
          if feature.get("zlib"):
              libs.append(feature.get("zlib"))
-@@ -883,7 +886,7 @@ class pil_build_ext(build_ext):
+@@ -894,7 +897,7 @@ class pil_build_ext(build_ext):
          if feature.get("xcb"):
              libs.append(feature.get("xcb"))
              defs.append(("HAVE_XCB", None))
@@ -150,7 +150,7 @@
              libs.extend(["kernel32", "user32", "gdi32"])
          if struct.unpack("h", b"\0\1")[0] == 1:
              defs.append(("WORDS_BIGENDIAN", None))
-@@ -920,7 +923,7 @@ class pil_build_ext(build_ext):
+@@ -931,7 +934,7 @@ class pil_build_ext(build_ext):
  
          if feature.get("lcms"):
              libs = [feature.get("lcms")]
@@ -159,16 +159,16 @@
                  libs.extend(["user32", "gdi32"])
              self._update_extension("PIL._imagingcms", libs)
          else:
-@@ -933,7 +936,7 @@ class pil_build_ext(build_ext):
+@@ -952,7 +955,7 @@ class pil_build_ext(build_ext):
          else:
-             self._remove_extension("PIL._webp")
+             self._remove_extension("PIL._avif")
  
 -        tk_libs = ["psapi"] if sys.platform in ("win32", "cygwin") else []
 +        tk_libs = ["psapi"] if host_platform in ("win32", "cygwin") else []
          self._update_extension("PIL._imagingtk", tk_libs)
  
          build_ext.build_extensions(self)
-@@ -949,7 +952,7 @@ class pil_build_ext(build_ext):
+@@ -968,7 +971,7 @@ class pil_build_ext(build_ext):
          print("-" * 68)
          print(f"version      Pillow {PILLOW_VERSION}")
          version = sys.version.split("[")
